Crate kcr_install_istio_io

Crate kcr_install_istio_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the install.istio.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

install.istio.io/v1alpha1

  • IstioOperator

Modules

v1alpha1